
# Slot: quantifier qualifier


Optional quantitative value indicating degree of expression.

URI: [biolink:gene_expression_mixin_quantifier_qualifier](https://w3id.org/biolink/vocab/gene_expression_mixin_quantifier_qualifier)


## Domain and Range

[GeneExpressionMixin](GeneExpressionMixin.md) &#8594;  <sub>0..1</sub> [OntologyClass](OntologyClass.md)

## Parents

 *  is_a: [quantifier qualifier](quantifier_qualifier.md)

## Children


## Used by

 * [GeneExpressionMixin](GeneExpressionMixin.md)
 * [GeneToGeneCoexpressionAssociation](GeneToGeneCoexpressionAssociation.md)
 * [VariantToGeneExpressionAssociation](VariantToGeneExpressionAssociation.md)
